<?php
/**
 * [Core]Pager：ページャークラス
 * ページャー表示に関する処理を行う
 *
 * @link http://komaphp.k-akimoto-matsu.net/Reference#subtitle0 リファレンス@Core.Pager
 * @author TakanoriMatsushige < http://k-akimoto-matsu.net/Inquiry >
 * @copyright k_akimoto_matsu. All Rights Reserved
 */
class Pager{

	/**
	 * 現在のページに表示するデータを返却する
	 * @param array $list 一覧のデータ
	 * @param number $page 現在のページ
	 */
	public static function thisPageList($list=[],$page=1,$cpage=0){
		if($cpage == 0){
			$cpage = Config::get("app","pager");
		}
		$start = 1 + ($cpage * ($page - 1)) - 1;
		$listData = [];

		$listData = array_slice($list,$start ,$cpage);

		return $listData;
	}

	/**
	 * ページャーHTMLを生成する
	 * @param number $page 現在のページ
	 * @param number $count データ個数
	 * @param string $listName ページ名
	 */
	public static function pagerHtml($page=1,$count=1,$listName,$cpage=0){

		if($cpage == 0){
			$cpage = Config::get("app","pager");
		}
		$pagerHtml=null;
		$pagerHtmls = [];

		$start = 1 + ($cpage * ($page - 1));
		$pageCnt = ceil($count / $cpage);
		$pagerHtml = "<ul class=\"pager\">\n";

		if($page > 1){
			if(($page-1) > 1){
				$pagerHtmls[] = "<li>".Html::link("{$listName}/1","&lt;&lt;",["title"=>"最初へ","alt"=>"最初へ"])."</li>";
			}
			$pagerHtmls[] = "<li>".Html::link("{$listName}/".($page-1),"&lt;",["title"=>($page-1)."ページ目へ","alt"=>($page-1)."ページ目へ"])."</li>";
		}

		$gn = 0;
		if($pageCnt > Config::get("app","pagersplit")){
			$l = null;
			for($i=1;$i<=$pageCnt;$i++){
				if($i < ($page - ( Config::get("app","pagersplit") / 2)) || $i > ($page + ( Config::get("app","pagersplit") / 2))) {
					if($gn == 0){
						$gn = $i;
					}

					$pagerHtmls[$gn] = "<li>...</li>";
					continue;
				}
				$l = $i;

				if($i == $page){
					$pagerHtmls[] = "<li class=\"current\">".Html::link("{$listName}/{$i}",$i)."</li>";
				}else{
					$pagerHtmls[] = "<li>".Html::link("{$listName}/{$i}",$i)."</li>";
				}
			}
			if($l < $pageCnt){
				$pagerHtmls[$i+1] = "<li>...</li>";
			}
		}else{
			for($i=1;$i<=$pageCnt;$i++){
				if($i == $page){
					$pagerHtmls[] = "<li class=\"current\">".Html::link("{$listName}/{$i}",$i)."</li>";
				}else{
					$pagerHtmls[] = "<li>".Html::link("{$listName}/{$i}",$i)."</li>";
				}
			}
		}

		if($pageCnt != $page){
			$pagerHtmls[] = "<li>".Html::link("{$listName}/".($page+1),"&gt;",["title"=>($page+1)."ページ目へ","alt"=>($page+1)."ページ目へ"])."</li>";
			if(($page+1) < $pageCnt){
				$pagerHtmls[] = "<li>".Html::link("{$listName}/".$pageCnt,"&gt;&gt;",["title"=>"最後へ","alt"=>"最後へ"])."</li>";
			}
		}
		//最後が何番目か算出
		$end = $start-1+$cpage;
		$endp = $page * $cpage;
		if(($count-$endp) < 0){
			$end = (($page-1) * $cpage) + ($count-(($page-1) * $cpage));
		}

		$pagerHtmls[] = "<li class=\"result\">&nbsp;全".$count."件中".$start."～".$end."番目を表示</li>";

		$pagerHtml .= join("\n",$pagerHtmls)."\n";
		$pagerHtml .= "</ul>\n";
		$pagerHtml .= "<div class=\"clear\"></div>\n";

		return $pagerHtml;
	}
}