<?php
/**
 * [Core]Session：セッションクラス
 * session関係のエイリアス
 *
 * @link http://komaphp.k-akimoto-matsu.net/Reference#subtitle0 リファレンス@Core.Session
 * @author TakanoriMatsushige < http://k-akimoto-matsu.net/Inquiry >
 * @copyright k_akimoto_matsu. All Rights Reserved
 */
class Session{

	/**
	 * session_startのエイリアス
	 */
	public static function start(){
		session_start();
	}
	/**
	 * $_SESSION[name]を取得
	 * @param unknown $name
	 * @return NULL|unknown
	 */
	public static function get($name=null){
		if($name == "" || $name == null){
			return null;
		}
		if(isset($_SESSION[$name])){
			return $_SESSION[$name];
		}else{
			return null;
		}
	}
	/**
	 * $_SESSION[name]を設定
	 */
	public static function set($name=null,$value){
		if($name == "" || $name == null){
			return null;
		}
		$_SESSION[$name] = $value;
	}
	/**
	 * $_SESSION[name]または$_SESSIONを破棄
	 */
	public static function destroy($name=null){
		if($name == "" || $name == null){
			session_unset();
			session_destroy();
		}
		unset($_SESSION[$name]);
	}
	/**
	 * セッションIDの再発行
	 * session_regenerate_id(true)のエイリアス
	 */
	public static function reg_id(){
		session_regenerate_id(true);
	}

	/**
	 * ワンタイムトークンを発行する
	 * @param unknown $keyword
	 * @return string
	 */
	public static function createToken($prefix = null){

		//セットされている場合は作らない //destroyをコントローラget()冒頭ですること。
		if(!is_null(self::get("fixToken"))) return self::get("fixToken");

		if(is_null($prefix)){
			$prefix = Config::get("app","SLASH");
		}

		$fixToken = hash(Config::get("app","hash_key"), $prefix."_".session_id()."_".rand(1,999));
		self::set("fixToken",$fixToken);
		return $fixToken;
	}

	/**
	 * ワンタイムトークンが正しいかチェックする
	 * @param unknown $token
	 * @return boolean
	 */
	public static function checkToken($token = null){
		$fixToken = self::get("fixToken");
		self::destroy("fixToken");

		//NULLはNG
		if(is_null($fixToken) || is_null($token)) return false;

		if($fixToken == $token){
			return true;
		}else{
			return false;
		}
	}
}